@@ -897,12 +897,16 @@ AGGREGATORS = {
 AGGREGATE_FNS = frozenset(AGGREGATORS.keys())
 
 
-def _is_literal(node):
+def node_is_literal(node) -> bool:
+    """
+    Detect whether a given node is itself a literal (Node_Literal), or if all its descendant nodes are literal
+    and the overall result is therefore a constant value that could be represented by a literal.
+    """
     if isinstance(node, Node_Literal):
         return True
     if hasattr(node, "children"):
         for sub in node.children:
-            if not _is_literal(sub):
+            if not node_is_literal(sub):
                 return False
         return True
     return False
@@ -913,7 +917,7 @@ def simplify_expression(node, context):
     Simplify an expression.  Currently only collapses operations between literals.
     """
     def simplify(node):
-        if not isinstance(node, Node_Literal) and _is_literal(node):
+        if not isinstance(node, Node_Literal) and node_is_literal(node):
             value = node.eval(context)
             return Node_Literal(value)
         if hasattr(node, "children"):
