@@ -1,4 +1,4 @@
-from urllib.parse import urlparse, unquote, urlunparse, quote
+from urllib.parse import urlparse
 import re
 import typing
 import json
@@ -6,7 +6,8 @@ import json
 
 def connect_to_database(uri: str, library: str=None, for_write: bool=False, dsl=None, **kwargs):
     """
-    Try, by various means, to connect to a database.
+    Try, by various means, to connect to a database.  If 'uri' points to a folder (a local folder or a remote folder
+    such as an s3 bucket), the files in that folder will be treated as tables
 
     :param uri:        URI of database.
     :param library:     A specific library to use, if available
@@ -19,10 +20,6 @@ def connect_to_database(uri: str, library: str=None, for_write: bool=False, dsl=
     libraries = []
     if library:
         libraries.append(library)
-    if ":" not in uri or "://" in uri:
-        # we can point to a folder and each file is treated as a table
-        from dslibrary.utils.folder_db import connect_to_folder_as_database
-        return connect_to_folder_as_database(uri, for_write=for_write, dsl=dsl, **kwargs)
     uri_parts = uri.split(":", maxsplit=1)
     if uri_parts[0] == "jdbc":
         uri_parts = uri_parts[1:]
@@ -41,6 +38,11 @@ def connect_to_database(uri: str, library: str=None, for_write: bool=False, dsl=
             conn = METHODS[lib](**params, for_write=for_write)
             if conn:
                 return conn
+    # uri could point to a folder, which we can treat as a database
+    if ":" not in uri or "://" in uri:
+        # we can point to a folder and each file is treated as a table
+        from dslibrary.utils.folder_db import connect_to_folder_as_database
+        return connect_to_folder_as_database(uri, for_write=for_write, dsl=dsl, **kwargs)
     raise ValueError(f"No driver installed/supported for {uri_parts[0]}")
 
 
@@ -249,51 +251,6 @@ def enquote_sql_identifier(name, allow_separator: bool=True, flavor: str=None):
     return name
 
 
-def dataframe_to_sql(dataframe, table_name: str, append: bool=False, flavor: str=None):
-    """
-    Generate SQL statements to create a table and add data.
-    :param dataframe:   A dataframe to render into SQL.
-    :param table_name:  Name of table to create or extend.
-    :param append:      True to append, False to replace.
-    :param flavor:      Name of a particular type of database, to adjust details of SQL format.
-    :returns a generator of (sql, parameter list)
-    """
-    enquote = lambda name, **k: enquote_sql_identifier(name, flavor=flavor, **k)
-    if not append:
-        yield "DROP TABLE IF EXISTS %s" % enquote(table_name), []
-    # TODO expand to cover more types
-    if flavor == "bigquery":
-        dtype_to_sql = {"int32": "INT64", "int64": "INT64", "float64": "NUMERIC", "datetime64": "TIMESTAMP"}
-        str_type = "STRING"
-    else:
-        dtype_to_sql = {"int32": "INTEGER", "int64": "INTEGER", "float64": "DOUBLE PRECISION", "datetime64": "TIMESTAMP"}
-        str_type = "VARCHAR"
-    cols = list(dataframe.columns)
-    types = []
-    for col, dtype in zip(cols, dataframe.dtypes):
-        sql_type = dtype_to_sql.get(str(dtype))
-        if not sql_type:
-            max_len = int(dataframe[col].str.len().max()) + 3
-            sql_type = f"{str_type}({max_len:d})"
-        types.append(sql_type)
-    rows = dataframe.itertuples(index=False, name=None)
-    fields = ", ".join("%s %s" % (enquote(col, allow_separator=False), t) for col, t in zip(cols, types))
-    yield "CREATE TABLE IF NOT EXISTS %s (%s)" % (enquote(table_name), fields), []
-    ins0 = "INSERT INTO %s (%s) VALUES " % (enquote(table_name), ", ".join(map(enquote, cols)))
-    sqls = []
-    params = []
-    for row in (rows or []):
-        sql = "(%s)" % ", ".join(map(lambda v: "%s", row))
-        sqls.append(sql)
-        params += list(row)
-        if len(sqls) >= 1000:
-            yield "%s%s" % (ins0, ", ".join(sqls)), params
-            sqls.clear()
-            params.clear()
-    if sqls:
-        yield "%s%s" % (ins0, ", ".join(sqls)), params
-
-
 def db_conn_flavor(connector) -> str:
     """
     Determine connector flavor.
