@@ -1,8 +1,9 @@
+import shutil
+import tempfile
 import unittest
-import pandas
 import mock
 
-from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2, \
+from dslibrary.utils.connect import _process_params, db_conn_flavor, connect_psycopg2, \
     connect_to_database, enquote_sql_identifier, connect_bigquery
 
 
@@ -42,24 +43,6 @@ class TestConnect(unittest.TestCase):
             'password': ''
         }, r
 
-    def test_dataframe_to_sql(self):
-        df = pandas.DataFrame({"x": [1, 2, 3], "y": [1.0, 2.0, 4.0], "z": ["one", "two", "three"]})
-        sqls = list(dataframe_to_sql(df, "t1"))
-        self.assertEqual(sqls, [
-            ('DROP TABLE IF EXISTS t1', []),
-            ('CREATE TABLE IF NOT EXISTS t1 (x INTEGER, y DOUBLE PRECISION, z VARCHAR(8))', []),
-            ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
-        ])
-
-    def test_dataframe_to_sql__bigquery(self):
-        df = pandas.DataFrame({"x": [1, 2, 3], "y": [1.0, 2.0, 4.0], "z": ["one", "two", "three"]})
-        sqls = list(dataframe_to_sql(df, "t1", flavor="bigquery"))
-        self.assertEqual(sqls, [
-            ('DROP TABLE IF EXISTS t1', []),
-            ('CREATE TABLE IF NOT EXISTS t1 (x INT64, y NUMERIC, z STRING(8))', []),
-            ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
-        ])
-
     def test_enquote_sql_identifier(self):
         # no flavor
         self.assertEqual('a', enquote_sql_identifier("a"))
@@ -134,3 +117,18 @@ class TestConnect(unittest.TestCase):
             cursor.execute("SQL")
             row = cursor.fetchone()
             self.assertEqual([1], row)
+
+    def test_connect_to_folder(self):
+        folder = tempfile.mkdtemp()
+        try:
+            db = connect_to_database(folder, for_write=True)
+            c = db.cursor()
+            c.execute("create table t1 (a integer); insert into t1 (a) values (1), (2), (3)")
+            c.execute("select * from t1")
+            cols = c.description
+            rows = c.fetchall()
+            self.assertEqual([(1,), (2,), (3,)], rows)
+            self.assertEqual("a", cols[0][0])
+            self.assertEqual("int64", cols[0][1])
+        finally:
+            shutil.rmtree(folder)
\ No newline at end of file
